package com.zskk.service;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jfinal.kit.HashKit;
import com.jfinal.weixin.sdk.api.ApiConfigKit;
import com.jfinal.weixin.sdk.api.ApiResult;
import com.jfinal.weixin.sdk.api.JsTicket;
import com.jfinal.weixin.sdk.api.JsTicketApi;
import com.jfinal.weixin.sdk.api.SnsAccessToken;
import com.jfinal.weixin.sdk.api.SnsAccessTokenApi;
import com.jfinal.weixin.sdk.api.SnsApi;
import com.jfinal.weixin.sdk.api.TemplateData;
import com.jfinal.weixin.sdk.api.TemplateMsgApi;
import com.jfinal.weixin.sdk.api.JsTicketApi.JsApiType;
import com.zskk.model.UserWechat;
import com.zskk.service.bean.WxJSConfigBean;

public class WeixinService {
	
	private static final Map<String, String> REMOTE_DIAGNOSIS_PATIENT_PAY_TEMPLATE_ID = new HashMap<String , String>(){{  
	     put("中世康恺电子胶片平台", "VZ0Y3yj6N6187EggHdtdUZYcdQ-UycrjKCZKjqLn60Y");  
	     put("河南省电子胶片平台", "DaOb3mBWUKTprlI4UEw8yVJUTTxJ79oRmxzbAqKPWU8"); 
	     put("黑龙江省电子胶片平台", "knCarFpiemuKVDT1VUCWUHOnAUd-VnYPHQY57akFzfQ"); 
	     put("辽宁省电子胶片平台", "N48qSAgAZBa206thUgRxZWy7fBKXROsJJhjLLXOYnxs");  
	 }}; 

	private static final Map<String, String> REMOTE_DIAGNOSIS_FINISH_TEMPLATE_ID = new HashMap<String , String>(){{  
		 put("中世康恺电子胶片平台", "5wIAbbe28AGQRW7NsPkCla8g_vfiimVOOXJ3Jd-rjBA");  
	     put("河南省电子胶片平台", "10OhHh4MwjjHJjv8Z44J7ZX5jKaB5PNRagJkH98GNPk");
	     put("黑龙江省电子胶片平台", "Xg6L3sIQA2oCWG6y-uO3AtfWBi_-7EALMGJDbk2GWSY"); 
	     put("辽宁省电子胶片平台", "f19uttgYUEtZsHqUFboDXOKb_bXdNjmnmXqGtYf7M1g");  
	 }}; 

	private static final Map<String, String> REMOTE_DIAGNOSIS_CANCEL_TEMPLATE_ID = new HashMap<String , String>(){{  
		 put("中世康恺电子胶片平台", "HuPWL7THvmw0J8svYAWo7_1_AKXwYO46RH2DbgMRGHU");  
	     put("河南省电子胶片平台", "cERKtFujCw3pXZJfBWzA2SaGyGt47aU-482Hl9BDkPc");
	     put("黑龙江省电子胶片平台", "IN35TBHt07AYejLKLmSpQadS_Mj_NKiLIUHZFuvrS88"); 
	     put("辽宁省电子胶片平台", "YvzOu-wh2j0QdXk7a2fTJvvF3w7ToR6LbB_Q6YinAhc");  
	 }}; 

	private static final Map<String, String> REMOTE_DIAGNOSIS_REFUND_TEMPLATE_ID = new HashMap<String , String>(){{  
		 put("中世康恺电子胶片平台", "34C7dwguVjn1zGAw1Qu-HFImnWwHa54A2WrAA0DLUHE");  
	     put("河南省电子胶片平台", "4SvFSB2Ix5KjFEhRI0aRru-hJqCZl4gpoS5DwTNF2YA");  
	     put("黑龙江省电子胶片平台", "2qPHn69_1yP4I5OT2u3Y4ifk7MBiG4JLWA5JE9ppujA");  
	     put("辽宁省电子胶片平台", "XvxA4I0N8ozVUqMjZUFbYPgzSNIvxMy1URt8tTlkzw0");  
	 }}; 
	 
	 private static final Map<String, String> LOCAL_EXAM_FINISH_TEMPLATE_ID = new HashMap<String , String>(){{  
		 put("中世康恺电子胶片平台", "w-tIiyXrwWziHGnPBnqq-FMMfiZTbtGbl5mDtLQt04A");  
	 }}; 
	 
	 private static final Map<String, String> LOCAL_REPORT_FINISH_TEMPLATE_ID = new HashMap<String , String>(){{  
		 put("中世康恺电子胶片平台", "5vu2mo8vwoFFdxQ2nXZJf-lymd3R80gb3JR_B3YpwKI");  
	 }}; 

	
	/*/
	 * 微信消息推送类型枚举
	 */
	public enum PUSH_TYPE {
		
		//远程诊断患者支付推送,远程诊断完成,远程诊断取消，远程诊断退款完成
		REMOTE_DIAGNOSIS_PATIENT_PAY(1),REMOTE_DIAGNOSIS_FINISH(2),REMOTE_DIAGNOSIS_CANCEL(3),REMOTE_DIAGNOSIS_REFUND(4),LOCAL_EXAM_FINISH(5),LOCAL_REPORT_FINISH(6);
		
		private int pushType;
		
		PUSH_TYPE(int pushType) {
			this.pushType = pushType;
		}
		
		public int getPushType() {
			return pushType;
		}
		
	}
	
	/**
	 * 用户同意授权，获取带code的url
	 * @return
	 * @throws UnsupportedEncodingException 
	 */
	public String getCodeUrl(String appId, String redirect_uri) throws UnsupportedEncodingException {
		String encode = URLEncoder.encode(redirect_uri, "UTF-8");
		String url = SnsAccessTokenApi.getAuthorizeURL(appId, encode, false);
		return url;
	}

	
	/**
	 * 用户同意授权，获取带code的url
	 * @return
	 * @throws UnsupportedEncodingException 
	 */
	public String getCodeUrl2(String appId, String redirect_uri) throws UnsupportedEncodingException {
		String encode = URLEncoder.encode(redirect_uri, "UTF-8");
		String url = SnsAccessTokenApi.getAuthorizeURL(appId, encode, true);
		return url;
	}
	/**
	 * 通过回调地址参数code获取access_token
	 * @param appId
	 * @param secret
	 * @param code
	 * @return
	 */
	public SnsAccessToken getWebAccessToken(String appId, String secret, String code) {
		SnsAccessToken snsAccessToken = SnsAccessTokenApi.getSnsAccessToken(appId, secret, code);
		return snsAccessToken;
	}
	
	/**
	 * 获取JsTicket，并生成JS-SDK调用参数
	 * @param requstUrl
	 * @return
	 */
	public WxJSConfigBean getWeixinJSSDKConfig(String requstUrl) {
		JsTicket jsTicket = JsTicketApi.getTicket(JsApiType.jsapi);
		String jsapi_ticket  = jsTicket.getTicket();
		String nonce_str 	 = create_nonce_str();
		String url 		     = requstUrl;
		String timestamp 	 = create_timestamp();
		String str 			 = "jsapi_ticket=" + jsapi_ticket + "&noncestr=" + nonce_str + "&timestamp=" + timestamp + "&url=" + url;
		String signature 	 = HashKit.sha1(str);
		
    	WxJSConfigBean wxJSConfigBean = new WxJSConfigBean();
    	wxJSConfigBean.setAppId(ApiConfigKit.getAppId());
    	wxJSConfigBean.setNonceStr(nonce_str);
    	wxJSConfigBean.setTimestamp(timestamp);
    	wxJSConfigBean.setSignature(signature);
		return wxJSConfigBean;
	}
    
	private String create_nonce_str() {
		return UUID.randomUUID().toString();
	}
	
	private static String create_timestamp() {
		return Long.toString(System.currentTimeMillis() / 1000);
	}
	/**
	 * 拉取用户信息
	 * @param accessToken
	 * @param openId
	 * @return
	 */
	public ApiResult getWebWeixinUserInfo(String accessToken, String openId) {
		ApiResult apiResult = SnsApi.getUserInfo(accessToken, openId);
		UserWechat userWechat = UserWechat.dao.findFirst("select * from user_wechat where wx_openid=?",openId);
		userWechat.setWxIcon(apiResult.getStr("headimgurl"));
		userWechat.setWxNickname(apiResult.getStr("nickname"));
		userWechat.update();
		return apiResult;
	}
	
	/*
	 * 发送模板消息
	 */
	public ApiResult sendTemplateMsg(String openid, String content, Integer pushtype, String source) {
		PUSH_TYPE type = null;
		ApiResult apiResult = null;
		for (PUSH_TYPE xxxEnum : PUSH_TYPE.values()) {
			if (xxxEnum.getPushType() == pushtype) {
				type = xxxEnum;
			}
		}
		switch (type) {
		case REMOTE_DIAGNOSIS_PATIENT_PAY:
		{
			String urlString = "https://wechat.pacsonline.cn/wx_patient/web/remoteDiagnosis?appId=" + ApiConfigKit.getAppId();
			JSONObject contentJson = JSON.parseObject(content);
			String out_trade_no = contentJson.getString("out_trade_no");
			String name = contentJson.getString("name");
			String name_utf8 = null;
			try {
				name_utf8 = URLDecoder.decode(name, "UTF-8");
			} catch (UnsupportedEncodingException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			String total_fee = contentJson.getString("total_fee");
			Double total_fee_double_value =  Double.valueOf(total_fee)/100;
            DecimalFormat df = new DecimalFormat("######0.00");
            String total_fee_to_yuan = df.format(total_fee_double_value);
            String template_id = REMOTE_DIAGNOSIS_PATIENT_PAY_TEMPLATE_ID.get(source);
			apiResult = sendRemoteDiagnosisPatientPayMsg(openid, urlString, out_trade_no, name_utf8, total_fee_to_yuan, template_id);
		}
			break;
			
		case REMOTE_DIAGNOSIS_FINISH:
		{
			String urlString = "https://wechat.pacsonline.cn/wx_patient/web/remoteDiagnosis?appId=" + ApiConfigKit.getAppId();
			JSONObject contentJson = JSON.parseObject(content);
			String out_trade_no = contentJson.getString("out_trade_no");
			String name = contentJson.getString("name");
			String name_utf8 = null;
			try {
				name_utf8 = URLDecoder.decode(name, "UTF-8");
			} catch (UnsupportedEncodingException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			String total_fee = contentJson.getString("total_fee");
            String template_id = REMOTE_DIAGNOSIS_FINISH_TEMPLATE_ID.get(source);
			apiResult = sendRemoteDiagnosisFinishMsg(openid, urlString, name_utf8, template_id);
		}
			break;
			
		case REMOTE_DIAGNOSIS_CANCEL:
		{
			String urlString = "https://wechat.pacsonline.cn/wx_patient/web/remoteDiagnosis?appId=" + ApiConfigKit.getAppId();
			JSONObject contentJson = JSON.parseObject(content);
			String out_trade_no = contentJson.getString("out_trade_no");
			String name = contentJson.getString("name");
			String total_fee = contentJson.getString("total_fee");
            String template_id = REMOTE_DIAGNOSIS_CANCEL_TEMPLATE_ID.get(source);
			apiResult = sendRemoteDiagnosisCancelMsg(openid, urlString, out_trade_no, template_id);
		}
			break;
			
		case REMOTE_DIAGNOSIS_REFUND:
		{
			String urlString = "https://wechat.pacsonline.cn/wx_patient/web/remoteDiagnosis?appId=" + ApiConfigKit.getAppId();
			JSONObject contentJson = JSON.parseObject(content);
			String out_trade_no = contentJson.getString("out_trade_no");
			String name = contentJson.getString("name");
			String total_fee = contentJson.getString("total_fee");
			Double total_fee_double_value =  Double.valueOf(total_fee)/100;
            DecimalFormat df = new DecimalFormat("######0.00");
            String total_fee_to_yuan = df.format(total_fee_double_value);
            String template_id = REMOTE_DIAGNOSIS_REFUND_TEMPLATE_ID.get(source);
			apiResult = sendRemoteDiagnosisRefundMsg(openid, urlString, out_trade_no, total_fee_to_yuan, template_id);
		}
			break;

		case LOCAL_EXAM_FINISH:
		{
			JSONObject contentJson = JSON.parseObject(content);
			String name = contentJson.getString("name");
			String modality = contentJson.getString("modality");
            String status = contentJson.getString("status");
            String study_id = contentJson.getString("study_id");
            String template_id = LOCAL_EXAM_FINISH_TEMPLATE_ID.get(source);
			String urlString = "https://wechat.pacsonline.cn/wx_patient/web/examPortrait?study_id=" + study_id;
			apiResult = sendLocalExamFinishMsg(openid, urlString, name, modality, status, template_id);
		}
		    break;
		    
		case LOCAL_REPORT_FINISH:
		{
			JSONObject contentJson = JSON.parseObject(content);
			String name = contentJson.getString("modality");
			String modality = contentJson.getString("name");
            String eaxmDate = contentJson.getString("eaxmDate");
            String report_id = contentJson.getString("report_id");
            String template_id = LOCAL_REPORT_FINISH_TEMPLATE_ID.get(source);
			String urlString = "https://wechat.pacsonline.cn/wx_patient/web/localReport?report_id=" + report_id;
			apiResult = sendLocalReportFinishMsg(openid, urlString, modality, name, eaxmDate, template_id);
		}
		    break;
		    
		default:
			break;
		}
		return apiResult;
	}
	
	public ApiResult sendRemoteDiagnosisPatientPayMsg(String openid, String url, String out_trade_no, String name, String total_fee, String template_id) {
		String str = " {\n" +
                "           \"touser\":\""+openid+"\",\n" +
                "           \"template_id\":\""+template_id+"\",\n" +
                "           \"url\":\""+url+"\",\n" +
                "           \"topcolor\":\"#FF0000\",\n" +
                "           \"data\":{\n" +
                "                   \"first\": {\n" +
                "                       \"value\":\"您好，你的远程诊断费用信息情况如下：\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword1\":{\n" +
                "                       \"value\":\""+out_trade_no+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword2\":{\n" +
                "                       \"value\":\""+name+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword3\":{\n" +
                "                       \"value\":\""+getNowDateString()+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword4\":{\n" +
                "                       \"value\":\""+total_fee+"元"+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword5\":{\n" +
                "                       \"value\":\"远程诊断专家咨询费\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"remark\":{\n" +
                "                       \"value\":\"祝您早日康复。\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   }\n" +
                "           }\n" +
                "       }";
        ApiResult apiResult = TemplateMsgApi.send(str);
        return apiResult;
	}
	
	public ApiResult sendRemoteDiagnosisFinishMsg(String openid, String url, String name, String template_id) {
		String str = " {\n" +
                "           \"touser\":\""+openid+"\",\n" +
                "           \"template_id\":\""+template_id+"\",\n" +
                "           \"url\":\""+url+"\",\n" +
                "           \"topcolor\":\"#FF0000\",\n" +
                "           \"data\":{\n" +
                "                   \"first\": {\n" +
                "                       \"value\":\"您好，你的远程诊断已完成\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword1\":{\n" +
                "                       \"value\":\""+name+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword2\":{\n" +
                "                       \"value\":\"远程诊断咨询意见单\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword3\":{\n" +
                "                       \"value\":\""+getNowDateString()+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"remark\":{\n" +
                "                       \"value\":\"祝您早日康复。\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   }\n" +
                "           }\n" +
                "       }";
        ApiResult apiResult = TemplateMsgApi.send(str);
        return apiResult;
	}
	
	public ApiResult sendRemoteDiagnosisCancelMsg(String openid, String url, String out_trade_no, String template_id) {
		String str = " {\n" +
                "           \"touser\":\""+openid+"\",\n" +
                "           \"template_id\":\""+template_id+"\",\n" +
                "           \"url\":\""+url+"\",\n" +
                "           \"topcolor\":\"#FF0000\",\n" +
                "           \"data\":{\n" +
                "                   \"first\": {\n" +
                "                       \"value\":\"您好，你的远程诊断申请已取消\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword1\":{\n" +
                "                       \"value\":\""+out_trade_no+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword2\":{\n" +
                "                       \"value\":\"取消申请\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"remark\":{\n" +
                "                       \"value\":\"谢谢您的使用。\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   }\n" +
                "           }\n" +
                "       }";
        ApiResult apiResult = TemplateMsgApi.send(str);
        return apiResult;
	}
	
	public ApiResult sendRemoteDiagnosisRefundMsg(String openid, String url, String out_trade_no, String total_fee, String template_id) {
		String str = " {\n" +
                "           \"touser\":\""+openid+"\",\n" +
                "           \"template_id\":\""+template_id+"\",\n" +
                "           \"url\":\""+url+"\",\n" +
                "           \"topcolor\":\"#FF0000\",\n" +
                "           \"data\":{\n" +
                "                   \"first\": {\n" +
                "                       \"value\":\"您好，你的远程诊断已完成退费\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword1\":{\n" +
                "                       \"value\":\""+out_trade_no+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword2\":{\n" +
                "                       \"value\":\""+total_fee+"元"+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword3\":{\n" +
                "                       \"value\":\""+getNowDateString()+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"remark\":{\n" +
                "                       \"value\":\"谢谢您的使用。\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   }\n" +
                "           }\n" +
                "       }";
        ApiResult apiResult = TemplateMsgApi.send(str);
        return apiResult;
	}
	
	public ApiResult sendLocalExamFinishMsg(String openid, String url, String name, String modality, String status, String template_id) {
		String str = " {\n" +
                "           \"touser\":\""+openid+"\",\n" +
                "           \"template_id\":\""+template_id+"\",\n" +
                "           \"url\":\""+url+"\",\n" +
                "           \"topcolor\":\"#FF0000\",\n" +
                "           \"data\":{\n" +
                "                   \"first\": {\n" +
                "                       \"value\":\"尊敬的"+ name + "先生/女士，您好，您的检查信息如下\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword1\":{\n" +
                "                       \"value\":\""+name+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword2\":{\n" +
                "                       \"value\":\""+modality+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword3\":{\n" +
                "                       \"value\":\""+status+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"remark\":{\n" +
                "                       \"value\":\"检查结束，请耐心等待\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   }\n" +
                "           }\n" +
                "       }";
        ApiResult apiResult = TemplateMsgApi.send(str);
        return apiResult;
	}
	
	public ApiResult sendLocalReportFinishMsg(String openid, String url, String modality, String name, String eaxmDate, String template_id) {
		String str = " {\n" +
                "           \"touser\":\""+openid+"\",\n" +
                "           \"template_id\":\""+template_id+"\",\n" +
                "           \"url\":\""+url+"\",\n" +
                "           \"topcolor\":\"#FF0000\",\n" +
                "           \"data\":{\n" +
                "                   \"first\": {\n" +
                "                       \"value\":\"您的检查报告结果已经出来了\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword1\":{\n" +
                "                       \"value\":\""+modality+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword2\":{\n" +
                "                       \"value\":\""+name+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"keyword3\":{\n" +
                "                       \"value\":\""+eaxmDate+"\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   },\n" +
                "                   \"remark\":{\n" +
                "                       \"value\":\"点击查看报告详情\",\n" +
                "                       \"color\":\"#173177\"\n" +
                "                   }\n" +
                "           }\n" +
                "       }";
        ApiResult apiResult = TemplateMsgApi.send(str);
        return apiResult;
	}
	
	private String getNowDateString() {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月dd日  HH:mm:ss");
		String time = sdf.format(new Date());
		return time;
	}
	public static String getParamByUrl(String url, String name) {
	    url += "&";
	    String pattern = "(\\?|&){1}#{0,1}" + name + "=[a-zA-Z0-9]*(&{1})";

	    Pattern r = Pattern.compile(pattern);

	    Matcher m = r.matcher(url);
	    if (m.find( )) {
//	        System.out.println(m.group(0));
	        return m.group(0).split("=")[1].replace("&", "");
	    } else {
	        return null;
	    }
	}

	public static void main(String[] args) {
//			DruidPlugin druidPlugin = new DruidPlugin("jdbc:mysql://www.pacsonline.cn:3306/pacsonline?useSSL=false", "pacs",
//					"ZSKK@2017~!@#".trim());
//			druidPlugin.start();
//			ActiveRecordPlugin arp = new ActiveRecordPlugin(druidPlugin);
//
//			_MappingKit.mapping(arp);
//			arp.start();
//
//			Report report = Report.dao.findById("9c11936e4a8440d6");
//		PUSH_TYPE dType2 = null;
//		 for(PUSH_TYPE xxxEnum : PUSH_TYPE.values()){
//	            if(xxxEnum.getPushType() == 1){
//	    			dType2 = xxxEnum;
//	    			System.out.println(xxxEnum);
//
//	            }
//	        }
//		 switch (dType2) {
//		case REMOTE_DIAGNOSIS_PATIENT_PAY:
//			System.out.println("sdas");
//
//			break;
//
//		default:
//			break;
//		}
//		PUSH_TYPE dType = PUSH_TYPE.REMOTE_DIAGNOSIS_PATIENT_PAY;
////			System.out.println(dType.getPushType());
//			URI fUri =new URI("http://www.163.com?a=aw&b-cd");
//			
//			fUri.getQuery();
//			String aString = getParamByUrl("http://www.163.com?a=aw&b-cd", "a");
//			System.out.println(aString);
			Double ddString =  Double.valueOf("2");
            DecimalFormat df = new DecimalFormat("######0.00");


			 System.out.println(df.format(ddString));


	}
}
